#Set the colors for the console window
$Host.Ui.RawUi.BackGroundColor = "Black"
$Host.Ui.RawUi.ForeGroundColor = "White"

#Clear the screen
cls

Function WriteHeading ($HeadingText)
{
	Write-Host
	Write-host "[" -foregroundcolor "DarkGray" -NoNewLine
	Write-host "[" -foregroundcolor "Gray" -NoNewLine
	Write-host "[" -foregroundcolor "White" -NoNewLine
	Write-host $HeadingText -foregroundcolor "green" -NoNewLine
	Write-host "]" -foregroundcolor "White" -NoNewLine
	Write-host "]" -foregroundcolor "Gray" -NoNewLine
	Write-host "]" -foregroundcolor "DarkGray"
	Write-Host
}

Function WriteValue ($Label, $Value)
{
	Write-Host $Label -foregroundcolor "Gray" -NoNewLine
	Write-Host ": " -foregroundcolor "Gray" -NoNewLine
	Write-Host $Value
}

Function WriteSuccess
{
	Write-Host ": " -foregroundcolor "Gray" -NoNewLine
	Write-Host Success -foregroundcolor "Green"
}


Function Get-Settings() {
	WriteHeading " Loading Settings "
	[xml]$settings = Get-Content .\settings.xml

	return $settings.settings
}


trap
{
	Write-Error $_.Exception
	break;
}
	 

[System.Xml.XmlElement]$settings = Get-Settings

if ($settings -eq $null) {
	return $false
}

$BootEntry = $settings.BootEntry
$Drive = $BootEntry.Drive
WriteValue "Drive" $Drive
$Path = $BootEntry.Path
WriteValue "Path" $Path 
$Description = $BootEntry.Description
WriteValue "Description" $Description 

WriteHeading " Copying Current Boot Entry "
$BootEntryCopy = bcdedit /copy '{current}' /d $BootEntry.Description
WriteSuccess

WriteHeading " Parsing New Boot Entry GUID "
$CLSID = $BootEntryCopy | ForEach-Object {$_.Remove(0,37).Replace(".","")} 
WriteSuccess
Write-Host
WriteValue "New Boot Entry GUID" $CLSID 

WriteHeading " Creating New Boot Entry "
$VHD = 'vhd=[' + $Drive + ':]\' + $Path
bcdedit /set $CLSID device $VHD
bcdedit /set $CLSID osdevice $VHD
bcdedit /set $CLSID detecthal on
Write-Host
WriteSuccess
Write-Host